# APIs

```{toctree}
---
maxdepth: 3
---
geo_erdos_renyi_network <geo_erdos_renyi_network>
geo_watts_strogatz_network <geo_watts_strogatz_network>
geo_barabasi_albert_network <geo_barabasi_albert_network>
ordering <ordering>
utils <utils>
```